<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="35"/>
        <location filename="../asciifile/asciifile.cpp" line="41"/>
        <source>Read ascii points</source>
        <translation>Punkte aus ASCII-Datei</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <source>shape file</source>
        <translation type="obsolete">Schablonendatei</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>ESRI Shapedaten importieren</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>Erster Basispunkt:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>Erster Zielpunkt:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>Zweiter Basispunkt:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>Zweiter Zielpunkt:</translation>
    </message>
</context>
<context>
    <name>LC_Gear</name>
    <message>
        <location filename="../gear/gear.cpp" line="33"/>
        <source>Gear creation plugin</source>
        <translation>Zahnrad Plugin</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="40"/>
        <source>Gear plugin</source>
        <translation>Zahnrad Plugin</translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>Objekte auflisten</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation>n</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>Leeres Objekt</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Layer</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="79"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="80"/>
        <source>Line type</source>
        <translation>Linientyp</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="81"/>
        <source>Line thickness</source>
        <translation>Linienstärke</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="82"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="88"/>
        <source>POINT</source>
        <translation>PUNKT</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="89"/>
        <location filename="../list/list.cpp" line="218"/>
        <source>in point</source>
        <translation>im Punkt</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="94"/>
        <source>LINE</source>
        <translation>LINIE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="99"/>
        <source>from point</source>
        <translation>von Punkt</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="102"/>
        <source>to point</source>
        <translation>zu Punkt</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="107"/>
        <location filename="../list/list.cpp" line="131"/>
        <source>length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="112"/>
        <source>Angle in XY plane</source>
        <translation>Winkel in XY Ebene</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="113"/>
        <source>Inc.</source>
        <translation>Ausdehnung</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="118"/>
        <source>ARC</source>
        <translation>KREISBOGEN</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="119"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="145"/>
        <source>center point</source>
        <translation>Mittelpunkt</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="125"/>
        <location filename="../list/list.cpp" line="139"/>
        <location filename="../list/list.cpp" line="222"/>
        <source>radius</source>
        <translation>Radius</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="126"/>
        <source>initial angle</source>
        <translation>Startwinkel</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="127"/>
        <source>final angle</source>
        <translation>Endwinkel</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="134"/>
        <source>CIRCLE</source>
        <translation>KREIS</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>circumference</source>
        <translation>Umfang</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="141"/>
        <source>area</source>
        <translation>Fläche</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>ELLIPSE</source>
        <translation>ELLIPSE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="148"/>
        <source>major axis</source>
        <translation>Hauptachse</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="166"/>
        <source>CONSTRUCTIONLINE</source>
        <translation>HILFSLINIE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="169"/>
        <source>OVERLAYBOX</source>
        <translation>OVERLAYBOX</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>SOLID</source>
        <translation>KÖRPER</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="176"/>
        <source>MTEXT</source>
        <translation>MTEXT</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="179"/>
        <source>TEXT</source>
        <translation>TEXT</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>INSERT</source>
        <translation>BLOCK</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="185"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>Insertion point</source>
        <translation>Einfügepunkt</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Scale</source>
        <translation>Skalierung</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="193"/>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="199"/>
        <source>Columns/Rows</source>
        <translation>Spalten/Reihen</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="203"/>
        <source>Column/Row Spacing</source>
        <translation>Spalten/Reihen Abstand</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>POLYLINE</source>
        <translation>POLYLINIE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="211"/>
        <source>Closed</source>
        <translation>Geschlossen</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>Vertices</source>
        <translation>Eckpunkte</translation>
    </message>
    <message>
        <source>curvature</source>
        <translation type="obsolete">Krümmung</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="227"/>
        <source>IMAGE</source>
        <translation>BILD</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="230"/>
        <source>SPLINE</source>
        <translation>SPLINE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="233"/>
        <source>SPLINEPOINTS</source>
        <translation>SPLINEPUNKTE</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="236"/>
        <source>HATCH</source>
        <translation>SCHRAFFUR</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="239"/>
        <source>DIMLEADER</source>
        <translation>BEMASSUNGSFÜHRUNG</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="242"/>
        <source>DIMALIGNED</source>
        <translation>BEMASSUNGAUSGERICHTET</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="245"/>
        <source>DIMLINEAR</source>
        <translation>BEMASSUNGLINEAR</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="248"/>
        <source>DIMRADIAL</source>
        <translation>BEMASSUNGRADIAL</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>DIMDIAMETRIC</source>
        <translation>BEMASSUNGDURCHMESSER</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="254"/>
        <source>DIMANGULAR</source>
        <translation>BEMASSUNGWINKEL</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="257"/>
        <source>UNKNOWN</source>
        <translation>UNBEKANNT</translation>
    </message>
    <message>
        <source>n %1: 
</source>
        <translation type="obsolete">n %1: 
</translation>
    </message>
    <message>
        <source>Empty Entity

</source>
        <translation type="obsolete">Leeres Objekt

</translation>
    </message>
    <message>
        <source>Layer: </source>
        <translation type="obsolete">Layer: </translation>
    </message>
    <message>
        <source>
 Color: </source>
        <translation type="obsolete">
 Farbe: </translation>
    </message>
    <message>
        <source> Line type: </source>
        <translation type="obsolete"> Linentyp: </translation>
    </message>
    <message>
        <source>
 Line thickness: </source>
        <translation type="obsolete">
 Linenstärke: </translation>
    </message>
    <message>
        <source>
 ID: %1
</source>
        <translation type="obsolete">
 ID: %1
</translation>
    </message>
    <message>
        <source>     in point: X=%1 Y=%2

</source>
        <translation type="obsolete">     Position: X=%1 Y=%2

</translation>
    </message>
    <message>
        <source>POINT: </source>
        <translation type="obsolete">PUNKT: </translation>
    </message>
    <message>
        <source>     from point: X=%1 Y=%2
     to point: X=%3 Y=%4
</source>
        <translation type="obsolete">     von Position: X=%1 Y=%2
     zu Position: X=%3 Y=%4
</translation>
    </message>
    <message>
        <source>   length: %1,</source>
        <translation type="obsolete">   Länge: %1,</translation>
    </message>
    <message>
        <source>  Angle in XY plane: %1
</source>
        <translation type="obsolete">  Winkel in XY Ebene: %1
</translation>
    </message>
    <message>
        <source>  Inc. X = %1,  Inc. Y = %2

</source>
        <translation type="obsolete">  X-Neigung = %1,  Y-Neigung = %2

</translation>
    </message>
    <message>
        <source>LINE: </source>
        <translation type="obsolete">LINIE: </translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>Gleiche Eigenschaften</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>Originalobjekt auswählen:</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>Objekte zum Ändern auswählen:</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>Beispiel Plugin</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="36"/>
        <source>Read PIC file</source>
        <translation>PIC Datei einlesen</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="42"/>
        <source>import PIC file</source>
        <translation>PIC Datei importieren</translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="229"/>
        <source>Read ascii points</source>
        <translation>Punkte aus ASCII-Datei</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>File...</source>
        <translation>Datei...</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="242"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space Separator</source>
        <translation>Leerzeichen getrennt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Tab Separator</source>
        <translation>Tabulator getrennt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Comma Separator</source>
        <translation>Komma getrennt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space in Columns</source>
        <translation>Feste Spaltenbreite</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>*.odb for Psion 2</source>
        <translation>*.odb für Psion 2</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="246"/>
        <source>Connect points</source>
        <translation>Punkte verbinden</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>2D Point</source>
        <translation>2D Punkt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>Draw 2D Point</source>
        <translation>Zeichne 2D Punkt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>3D Point</source>
        <translation>3D Punkt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>Draw 3D Point</source>
        <translation>Zeichne 3D Punkt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Point Number</source>
        <translation>Punkt Nummer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Draw point number</source>
        <translation>Zeichne Punkt Nummer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Point Elevation</source>
        <translation>Höhenpunkt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Draw point elevation</source>
        <translation>Zeichne Höhenpunkt</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Point Code</source>
        <translation>Punkt Code</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Draw point code</source>
        <translation>Zeichne Punkt Code</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="272"/>
        <source>Accept</source>
        <translation>Übernehmen</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="277"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="307"/>
        <source>Select file</source>
        <translation>Datei auswählen</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="314"/>
        <source>Point 2D layer is empty</source>
        <translation>Layer 2D Punkt ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="317"/>
        <source>Point 3D layer is empty</source>
        <translation>Layer 3D Punkt ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point elevation layer is empty</source>
        <translation>Layer Höhenpunkt ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="321"/>
        <source>Point elevation height is empty</source>
        <translation>Höhe Höhenpunkt ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="322"/>
        <source>Point elevation separation is empty</source>
        <translation>Abstand Höhenpunkt ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="325"/>
        <source>Point number layer is empty</source>
        <translation>Layer Punkt Nummer ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point number height is empty</source>
        <translation>Höhe Punkt Nummer ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point number separation is empty</source>
        <translation>Abstand Punkt Nummer ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="330"/>
        <source>Point code layer is empty</source>
        <translation>Layer Punkt Code ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point code height is empty</source>
        <translation>Höhe Punkt Code ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point code separation is empty</source>
        <translation>Abstand Punkt Code ist leer</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="360"/>
        <source>The file %1 not exist</source>
        <translation>Die Datei %1 existiert nicht</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="365"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Kann Datei %1 nicht öffnen</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>Datei...</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>Dateityp:</translation>
    </message>
    <message>
        <source>Unknoun</source>
        <translation type="obsolete">Unbekannt</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>ESRI Shapedaten importieren</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>Aktuelles</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>Aus Daten:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>Linientyp</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>Punkt</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>als Punkt</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>als Bezeichner:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>Übernehmen</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>Datei auswählen</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translation>Punkt und Maße</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation>3D Punkt</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation>Mehrfachpunkte</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation>Mehrfachpunkte und Maße</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation>3D Mehrfachpunkte</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>Bogen</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation>Bogen und Maße</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation>3D Bogen</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>Polygon</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation>Polygon+Abmessung</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation>3D Polygon</translation>
    </message>
    <message>
        <source>Poligon</source>
        <translation type="obsolete">Polygon</translation>
    </message>
    <message>
        <source>Poligon+Measure</source>
        <translation type="obsolete">Polygon und Maße</translation>
    </message>
    <message>
        <source>3D Poligon</source>
        <translation type="obsolete">3D Polygon</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translation>Mehrfachmuster</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>Die Datei %1 hat keine .shp Erweiterung</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>Die Datei %1 existiert nicht</translation>
    </message>
</context>
<context>
    <name>lc_Geardlg</name>
    <message>
        <location filename="../gear/gear.cpp" line="66"/>
        <source>Draw a gear</source>
        <translation>Ein Zahnrad erstellen</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="71"/>
        <source>Number of teeth</source>
        <translation>Anzahl Zähne</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="79"/>
        <source>Circular pitch</source>
        <translation>Teilkreisdurchmesser</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="87"/>
        <source>Pressure angle (deg)</source>
        <translation>Eingriffswinkel (Grad)</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="95"/>
        <source>Addendum</source>
        <translation>Zahnkopfhöhe</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="103"/>
        <source>Dedendum</source>
        <translation>Zahnfusshöhe</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="111"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="114"/>
        <source>Spur</source>
        <translation>Stirnrad</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="115"/>
        <source>Ring</source>
        <translation>Hohlrad</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="119"/>
        <source>Accept</source>
        <translation>Übernehmen</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="124"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="274"/>
        <source>List entities</source>
        <translation>Objekte auflisten</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>Zeichne Linie</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>Anfang X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>Anfang Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>Ende X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>Ende Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>Übernehmen</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>Anfang X ist leer</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>Anfang Y ist leer</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>Ende X ist leer</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>Ende Y ist leer</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>Beispiel Plugin</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="65"/>
        <source>File...</source>
        <translation>Datei...</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="75"/>
        <source>Scale:</source>
        <translation>Skalierung:</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="79"/>
        <source>Accept</source>
        <translation>Übernehmen</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="83"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="111"/>
        <source>Select file</source>
        <translation>Datei auswählen</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="119"/>
        <source>Scale Factor is empty or invalid</source>
        <translation>Skalierungsfaktor ist leer oder ungültig</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="132"/>
        <source>The file %1 not exist</source>
        <translation>Die Datei %1 existiert nicht</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="137"/>
        <source>Can&apos;t open the file %1</source>
        <translation>Kann Datei %1 nicht öffnen</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="144"/>
        <source>%1 objects imported</source>
        <translation>%1 Objekte importiert</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="166"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation>PIC Import: Erster Punkt ist leer %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="179"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation>PIC Import: Endpunkt ist leer %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="258"/>
        <location filename="../picfile/picfile.cpp" line="267"/>
        <source>format error in %1</source>
        <translation>Formatfehler in %1</translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation>Plot Plugin</translation>
    </message>
    <message>
        <source>plugins_menu</source>
        <translation type="obsolete">plugins_menu</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="obsolete">Zeichnen</translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation>Gleichung plotten</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation>Dieses Plugin ermöglicht es mathematische Gleichungen zu plotten.
Wenn man nicht die parametrische Form verwenden möchte, lässt man einfach &quot;Gleichung 2&quot; weg.
Man kann pi verwenden, wenn der Wert von Pi (d. h. (3*pi)) benötigt wird.
Als Variable/Parameter der Gleichung kann t oder x verwendet werden.
</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation>Gleichung 1:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation>Gleichung 2:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation>Anfangswert:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation>Endwert:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation>Schrittweite:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation>Zeichnen</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation>Liniensegmente</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation>Polylinie</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation>Splinepunkte</translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="175"/>
        <source>Layer:</source>
        <translation>Layer:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="207"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="208"/>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <source>Heigth:</source>
        <translation type="obsolete">Höhe:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="209"/>
        <source>Separation</source>
        <translation>Teilung</translation>
    </message>
</context>
</TS>
